<?php

namespace Modules\CommunityManager\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\CommunityManager\Entities\Community;
use Modules\CommunityManager\Entities\CommunitiesSubDetails;
use Modules\CommunityManager\Entities\CommunitiesAnswers;
use Modules\CommunityManager\Http\Requests\CommunityRequest;
use DB;

class CommunityManagerController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index(Request $request)
    {
		$allowed_columns = ['id', 'title', 'description','status','created_at','updated_at'];
        $sort = in_array($request->get('sort'), $allowed_columns) ? $request->get('sort') : 'created_at';
        $order = $request->get('direction') === 'asc' ? 'asc' : 'desc';
        $communities = Community::status(request('status'))->filter(request('keyword'))->orderBy($sort, $order)->paginate(config('get.ADMIN_PAGE_LIMIT'));
		return view('communitymanager::Admin.index', compact('communities'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        return view('communitymanager::Admin.createOrUpdate');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
     public function store(CommunityRequest $request) {
		 
		// print_R($_POST);die;
		try {
            $community = new Community();
            $community->title = $request->title;
            $community->description = $request->description;
            $community->status = $request->status;
            $community->color_code = str_replace("#","",$request->color_code);
            $community->save();
			$sub_details = array(); 
			foreach($request->subdetails['title'] as $k=>$v){
				$sub_details[$k]['sub_title'] = $v;
			}
			foreach($request->subdetails['questions'] as $k=>$v){
				$sub_details[$k]['questions'] = $v;
			}
			foreach($request->subdetails['answer'] as $k=>$v){
				$sub_details[$k]['answer'] = $v;
			}
			//print_R($sub_details); die;
			foreach($sub_details as $key=>$val){
				$community_details = new CommunitiesSubDetails();
				$community_details->community_id 	= $community->id;
				$community_details->sub_title 		= $val['sub_title'];
				$community_details->questions 		= $val['questions'];
				$community_details->save(); 
				foreach($val['answer']  as $k=>$v){
					$community_answer 							= new CommunitiesAnswers();
					$community_answer->community_subdetail_id 	= $community_details->id;
					$community_answer->answer 					= $v;
					$community_answer->save();
				}
			}
			
			DB::table('settings')->where('slug', 'LASTUPDATE')->update(['config_value' => date('Y-m-d H:s:i')]);
			
          ////  \Mail::to($user->email)->send(new VerifyAdminUserMail($user,  $request->password));
        } catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('admin.community')->with('success', 'community has been saved Successfully');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
		$community = Community::with(['SubDetails'=>function($q){
			return $q->with(['Answer']);
        }])->find($id);
      
		return view('communitymanager::Admin.show', compact('community'));
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
		$community = Community::with(['SubDetails'=>function($q){
			return $q->with(['Answer']);
		}])->find($id);
        $community->color_code = '#'.$community->color_code; 
		return view('communitymanager::Admin.createOrUpdate', compact('community'));
    }

    
    /**
     * Update the specified resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function update(CommunityRequest $request, $id) {
		//print_R($_POST);die;
        try {

            $community = Community::find($id);
            $community->title = $request->title;
            $community->description = $request->description;
            $community->status = $request->status;
            $community->color_code = str_replace("#","",$request->color_code);
            $community->save();
			
			$sub_details = array(); 
			foreach($request->subdetails['id'] as $k=>$v){
				$sub_details[$k]['id'] = $v;
			}
			foreach($request->subdetails['title'] as $k=>$v){
				$sub_details[$k]['sub_title'] = $v;
			}
			foreach($request->subdetails['questions'] as $k=>$v){
				$sub_details[$k]['questions'] = $v;
			}
			foreach($request->subdetails['answer'] as $k=>$v){
				$sub_details[$k]['answer'] = $v;
			}
			//print_R($sub_details);die;
			foreach($sub_details as $key=>$val){
				$community_details = CommunitiesSubDetails::find($val['id']);
				$community_details->community_id 	= $community->id;
				$community_details->sub_title 		= $val['sub_title'];
				$community_details->questions 		= $val['questions'];
				$community_details->save(); 
				
				CommunitiesAnswers::where('community_subdetail_id',$val['id'])->delete();
				
				foreach($val['answer']  as $k=>$v){
					$community_answer 							= new CommunitiesAnswers();
					$community_answer->community_subdetail_id 	= $community_details->id;
					$community_answer->answer 					= $v;
					$community_answer->save();
				}
			}
			
			DB::table('settings')->where('slug', 'LASTUPDATE')->update(['config_value' => date('Y-m-d H:s:i')]);
			
        } catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('admin.community')->with('success', 'Comunity has been updated Successfully');
    }


    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy($id)
    {
       $getPageUpdated = Community::where('id', '=', $id)->delete();
       $responce = ['status' => true, 'message' => 'Comunity has been deleted successfully !!', 'data' => ['id' => $id]];

        return $responce;
    }
}
