<?php

namespace Modules\UserManager\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\UserManager\Entities\User;
use Modules\UserManager\Http\Requests\UserRequest;
use Illuminate\Support\Facades\DB;
use App\Mail\VerifyAdminUserMail;

class UsersController extends Controller {

    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index(Request $request) {
        $allowed_columns = ['id', 'name', 'email','status','is_verified','created_at'];
        $sort = in_array($request->get('sort'), $allowed_columns) ? $request->get('sort') : 'created_at';
        $order = $request->get('direction') === 'asc' ? 'asc' : 'desc';
        $users = User::status(request('status'))->filter(request('keyword'))->orderBy($sort, $order)->paginate(config('get.ADMIN_PAGE_LIMIT'));
        return view('usermanager::Admin.index', compact('users'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create() {

        return view('usermanager::Admin.createOrUpdate');
    }

    /**
     * Store a newly created resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function store(UserRequest $request) {
        try {
            $user = new User();
            $user->name = $request->name;
            //$user->last_name = $request->last_name;
            $user->email = $request->email;
            $user->status = $request->status;
            $user->phone = !empty($request->phone) ? $request->phone : "";
            $user->is_verified = $request->is_verified;
            $user->verification_code = str_random(8);
            if (empty($request->input('password'))) {
                unset($request['password']);
            } else {
                $user->password = $request['password'] = Hash::make($request->input('password'));
            }

            if ($request->has('photo')) {
                $filee = $request->file('photo');
                $destinationPath = public_path('uploads/users');
                $file_name = pathinfo($filee->getClientOriginalName(), PATHINFO_FILENAME);
                $file_name = str_replace(' ', '-', $file_name);
                $filename = $file_name . '-' . time() . '.' . $filee->getClientOriginalExtension();
                $filee->move($destinationPath, $filename);
                $user->photo = $filename;
            }

            $user->save();

            \Mail::to($user->email)->send(new VerifyAdminUserMail($user,  $request->password));
        } catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('admin.users')->with('success', 'User has been saved Successfully');
    }

    /**
     * Show the specified resource.
     * @return Response
     */
    public function show($id) {
        $user = User::find($id);
        return view('usermanager::Admin.show', compact('user'));
    }

    /**
     * Show the form for editing the specified resource.
     * @return Response
     */
    public function edit($id) {

        $user = User::find($id);
        return view('usermanager::Admin.createOrUpdate', compact('user'));
    }

    /**
     * Update the specified resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function update(UserRequest $request, $id) {
        try {

            $user = User::find($id);
            $user->name = $request->name;
            //$user->last_name = $request->last_name;
            $user->email = $request->email;
            $user->status = $request->status;
            $user->phone = !empty($request->phone) ? $request->phone : "";
            $user->is_verified = $request->is_verified;
            if (empty($request->input('password'))) {
                unset($request['password']);
            } else {
                $user->password = $request['password'] = Hash::make($request->input('password'));
            }
            //   dd($request);
            if ($request->has('photo')) {
                $filee = $request->file('photo');
                $destinationPath = public_path('uploads/users');
                $file_name = pathinfo($filee->getClientOriginalName(), PATHINFO_FILENAME);
                $file_name = str_replace(' ', '-', $file_name);
                $filename = $file_name . '-' . time() . '.' . $filee->getClientOriginalExtension();
                $filee->move($destinationPath, $filename);
                $user->photo = $filename;
            }
            //   dd($user);
            //  $user->fill($request->all());

            $user->save();
        } catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('admin.users')->with('success', 'User has been updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     * @return Response
     */
    public function destroy($id) {
        DB::beginTransaction();
        $user = User::where('id', '=', $id)->first();
        // dd($category->products->count());
        try {
            $user->delete();
            DB::commit();
            $responce = ['status' => true, 'message' => 'This user has been deleted Successfully!', 'data' => $user];
        } catch (\Exception $e) {
            DB::rollBack();
            $responce = ['status' => false, 'message' => $e->getMessage()];
        }
        return $responce;
    }

}
