@extends('layouts.admin.master')
@section('title','User Manager')
@section('content')
@include('layouts.admin.flash.alert')
<!-- Content Header (Page header) -->
<section class="content-header">
    <h1>
        Manage Users
        <small>Here you can manage users</small>
    </h1>
    {{ Breadcrumbs::render('common',['append' => [['label'=> $getController,'route'=> \Request::route()->getName()]]]) }}
</section>

<section class="content" data-table="pages">
    <div class="row pages">
        <div class="col-md-12">
            <div class="box box-info">
                <div class="box-header">
                    <h3 class="box-title"><span class="caption-subject font-green bold uppercase">{{ __('List Users') }}</span></h3>
                    <div class="box-tools">
                        <a href="{{route('admin.users.add')}}" class="btn btn-success btn-flat"><i class="fa fa-plus"></i> Add New User</a>
                    </div>
                </div><!-- /.box-header -->
                <div class="box-body table-responsive">
                    {{ Form::open(['url' => route('admin.users'),'method' => 'get']) }}
                    <div class="col-md-12">
                        <div class="row">
                            <div class="col-md-2 form-group">
                                {{ Form::select('status', ['' => 'All',1 => 'Active', 0 => 'Inactive'], app('request')->query('status'), ['class' => 'form-control']) }}
                            </div>
                            <div class="col-md-5 form-group">
                                {{ Form::text('keyword', app('request')->query('keyword'), ['class' => 'form-control','placeholder' => 'Keyword e.g: name, email']) }}
                            </div>
                            <div class="col-md-3 form-group">
                                <button class="btn btn-success" title="Search" type="submit"><i class="fa fa-filter"></i> Filter</button>
                                <a href="{{ route('admin.users') }}" class="btn btn-warning" title="Cancel"><i class="fa fa-fw fa-refresh"></i> Reset</a>
                            </div>
                        </div>
                    </div>
                    {{ Form::close() }}
                    <table class="table table-hover table-striped">
                        <thead>
                            <tr>
                                <th>#</th>
                                <th scope="col"> @php
                                    $sorting['sort'] = "name";
                                    $sorting['direction'] = request()->direction == 'asc' ? 'desc' : 'asc';
                                    @endphp
                                    <a href="{{ URL::route('admin.users',$sorting) }}">First Name</a></th>
								<th scope="col">Photo</th>
                                <th scope="col">@php
                                    $sorting['sort'] = "email";
                                    $sorting['direction'] = request()->direction == 'asc' ? 'desc' : 'asc';
                                    @endphp
                                    <a href="{{ URL::route('admin.users',$sorting) }}">Email</a></th>
                                <th scope="col">@php
                                    $sorting['sort'] = "status";
                                    $sorting['direction'] = request()->direction == 'asc' ? 'desc' : 'asc';
                                    @endphp
                                    <a href="{{ URL::route('admin.users',$sorting) }}">Status</a></th>
                                <th scope="col">@php
                                    $sorting['sort'] = "is_verified";
                                    $sorting['direction'] = request()->direction == 'asc' ? 'desc' : 'asc';
                                    @endphp
                                    <a href="{{ URL::route('admin.users',$sorting) }}">Verified</a></th>
                                <th scope="col" width="18%">@php
                                    $sorting['sort'] = "created_at";
                                    $sorting['direction'] = request()->direction == 'asc' ? 'desc' : 'asc';
                                    @endphp
                                    <a href="{{ URL::route('admin.users',$sorting) }}">Created</a></th>
                                <th scope="col" class="actions" width="12%">Action</th>
                            </tr>
                        </thead>
                        @if($users->count() > 0)
                        <tbody>
                            @php
                            $i = (($users->currentPage() - 1) * ($users->perPage()) + 1)
                            @endphp
                            @foreach($users as $user)
                            <tr class="row-{{ $user->id }}">
                                <td> {{$i}}. </td>
                                <td>{{$user->name}}</td>
                                <td>@php
                                    $filepath = '/uploads/users/';
                                    @endphp


                                    @if(!empty($user->photo) && file_exists(public_path() . $filepath . $user->photo))
                                    <?php $imageurl = \App\Helpers\MenuHelpers::imageUrl(url($filepath . $user->photo), '100', '100', '100'); ?>

                                    @else
                                    <?php $imageurl = \App\Helpers\MenuHelpers::imageUrl(url('img/no_image.gif'), '100', '100', '100'); ?>
                                    @endif

                                    <img src="{{ $imageurl  }}" class=" img-responsive img-thumbnail" alt="{{ $user->name}}">      
                                </td>
                                <td>{{$user->email}}</td>
                                <td>{{  $user->status == 1 ? "Active" : "In-Active" }}</td>
                                <td>{{  $user->is_verified == 1 ? "Verified" : "Not Verified" }}</td>
                                <td>{{ $user->created_at->format(config('get.ADMIN_DATE_TIME_FORMAT')) }}</td>
                                <td class="actions">
                                    <div class="form-group">
                                        <a href="{{ route('admin.users.view',['id' => $user->id]) }}" class="btn btn-warning btn-sm btn-flat" data-toggle="tooltip" alt="View" title="" data-original-title="View"><i class="fa fa-fw fa-eye"></i></a> 
                                        <a href="{{ route('admin.users.edit',['id' => $user->id]) }}" class="btn btn-primary btn-sm btn-flat" data-toggle="tooltip" alt="Edit" title="" data-original-title="Edit"><i class="fa fa-edit"></i></a>
                                        <a href="javascript:void(0);" class="confirmDeleteBtn reload btn btn-danger btn-sm btn-flat"  alt="Delete {{ $user->name }}" data-url="{{ route('admin.users.delete', $user->id) }}" data-title="{{ $user->name }}"><i class="fa fa-trash"></i></a>
                                    </div>
                                </td>
                            </tr>
                            @php
                            $i++;
                            @endphp
                            @endforeach
                        </tbody>
                        @else
                        <tfoot>
                            <tr>
                                <td colspan='7' align='center'> <strong>Record Not Available</strong> </td>
                            </tr>
                        </tfoot>
                        @endif
                    </table>
                </div>
                <div class="box-footer clearfix">
                    {{ $users->appends(Request::query())->links() }}
                </div>
            </div>
        </div>
    </div>
</section>
@stop
