<?php

namespace Modules\AdvertisementPackageManager\Http\Controllers\Admin;
 
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\AdvertisementPackageManager\Entities\Package;
use Modules\AdvertisementPackageManager\Entities\PackagePrice;
use Modules\AdvertisementPackageManager\Entities\PackageFeature;
use Modules\PriceRangeManager\Entities\PriceRange;
use Illuminate\Support\Facades\DB;
use Modules\AdvertisementPackageManager\Http\Requests\PackageRequest;

class PackageController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index(Request $request)
    {
        //return view('advertisementpackagemanager::Admin.index');
        $allowed_columns = [ 'title'];
        
        $order = $request->get('direction') === 'asc' ? 'asc' : 'asc';
       
        $packages = Package::filter($request->query('keyword'))->status(request('status'))->orderBy('title', 'desc')->paginate(config('get.ADMIN_PAGE_LIMIT'));
        
        return view('advertisementpackagemanager::admin.index', compact('packages'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
         $ranges=PriceRange::orderBy('id')->get();
        return view('advertisementpackagemanager::admin.createOrUpdate',compact('ranges'));
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(PackageRequest $request)
    {
        DB::beginTransaction();
        try{
        $inputs =  $request->except(['package_features','package_prices']);
           $package = Package::create($inputs);
          /* save package features  */
           if(!empty($request->only(['package_features']))){
            $features=[];
            $Data = $request->only(['package_features']);
             foreach($Data['package_features'] as $record){
                if(!empty($record) && $record['title']!=Null && $record['value']!=Null){
                     $features[] = new PackageFeature($record);
                }
            }
           
            $package->package_features()->saveMany($features);
          }
          /* save package prices  */
          if(!empty($request->only(['package_prices']))){
            $prices=[];
            $Data = $request->only(['package_prices']);
            foreach($Data['package_prices'] as $record){
                if(!empty($record) && $record['price_range_id']!=Null && $record['price']!=Null){
                      $prices[] = new PackagePrice($record);
                   }
            }
             $package->package_prices()->saveMany($prices);
          }
         
        DB::commit();
        }
        catch (\Illuminate\Database\QueryException $e) {
            DB::rollBack();
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('data.packages', app('request')->query())->with('success', 'Package has been saved Successfully');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
        DB::beginTransaction();
        try{
            $package = Package::where('id' ,'=', $id)->first();
         
        DB::commit();
        }
        catch (\Illuminate\Database\QueryException $e) {
            DB::rollBack();
            return back()->withError($e->getMessage())->withInput();
        }
        
        return view('advertisementpackagemanager::admin.show',compact('package'));
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        DB::beginTransaction();
        try{
            $package = Package::where('id' ,'=', $id)->first();
            $ranges=PriceRange::orderBy('id')->get();
         
        DB::commit();
        }
        catch (\Illuminate\Database\QueryException $e) {
            DB::rollBack();
            return back()->withError($e->getMessage())->withInput();
        }
        return view('advertisementpackagemanager::admin.createOrUpdate', compact('package','ranges'));
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(PackageRequest $request, $id)
    {
         //dd($request->all());
         DB::beginTransaction();
         try{
             $package = Package::find($id);
 
             $package->fill($request->except(['package_features','package_prices']));
             $package->save();
             if(!empty($request->only(['package_features']))){
                 $features=[];
                 $Data = $request->only(['package_features']);
                 $existingfeatures=$package->package_features->pluck('id','title')->toArray();
                foreach($Data['package_features'] as $record){
                     if(array_key_exists($record['title'],\Config::get('constant.package_features'))){
                         if(!empty($record) && $record['title']!=Null && $record['value']!=Null){
                             if(array_key_exists($record['title'],$existingfeatures)){
                                 PackageFeature::whereId($existingfeatures[$record['title']])->update($record);
                             }
                             else{
 
                                 $features[] = new PackageFeature($record);
                             }
                            
                     }
 
                     }else{
                        PackageFeature::where('title',$record['title'])->delete();
                     }
                 }
                 $package->package_features()->saveMany($features);
 
               }
               if(!empty($request->only(['package_prices']))){
                $prices=[];
                $Data = $request->only(['package_prices']);
                $existingprices=$package->package_prices->pluck('id','price_range_id')->toArray();
               $remainPackageIds=[];
               foreach($Data['package_prices'] as $record){
                $remainPackageIds[]=$record['price_range_id'];
                            if(array_key_exists($record['price_range_id'],$existingprices)){
                                PackagePrice::whereId($existingprices[$record['price_range_id']])->update($record);
                            }
                            else{

                                $prices[] = new PackagePrice($record);
                            }
                           }
                
                $package->package_prices()->saveMany($prices);
                PackagePrice::whereNotIn('price_range_id',$remainPackageIds)->where('package_id',$package->id)->delete();
              }
 
             DB::commit();
           }
           catch (\Illuminate\Database\QueryException $e) {
             DB::rollBack();
             return back()->withError($e->getMessage())->withInput();
           }
         return redirect()->route('data.packages', app('request')->query())->with('success', 'Package has been updated Successfully');
    
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy($id)
    {
         try{
            $package = Package::find($id);
            $package->package_features()->delete();
            $package->package_prices()->delete();
            $package->delete();
           $responce =  ['status' => true,'message' => 'This Package has been deleted Successfully!','data' => $package];
        }
        catch (\Exception $e)
        {
            $responce =  ['status' => false,'message' => $e->getMessage()];
        }
        return $responce;
    }
}
