<?php

namespace Modules\BannerManager\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;

use Modules\BannerManager\Entities\BannerCategory;
use Modules\BannerManager\Entities\BannerImage;
use Modules\BannerManager\Http\Requests\BannerRequest;

use DB;

class BannerCategoryController extends Controller
{

    
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index(Request $request)
    {   
         $allowed_columns = ['id', 'heading'];
        $sort = in_array($request->get('sort'), $allowed_columns) ? $request->get('sort') : 'created_at';
        $order = $request->get('direction') === 'asc' ? 'asc' : 'desc';
        $banners = BannerCategory::status($request->query('status'))->filter($request->query('keyword'))->orderBy($sort, $order)->paginate(config('get.ADMIN_PAGE_LIMIT'));
        return view('bannermanager::Admin.banners.index',compact('banners'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        return view('bannermanager::Admin.banners.add');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(BannerRequest $request)
    {  
     
         try{
             $banner = BannerCategory::create($request->all());
            // $last=BannerCategory::latest()->first();
            // dd($last->id);
            
            if(isset($request->banner_images) > 0)
            { 
             $images =[];
                foreach ($request->banner_images as $key => $value) {

                #### move file from temp to banner-images ####
                    $destination='/banner-images/';

                    $img_name=$value['image'];
   
                   \Storage::disk('public')->move(
                   'temp/' . $img_name, $destination . $img_name);

                #### move file from temp to banner-images ####
                  
                    $images[] = new BannerImage($value);
                    
                }

                $banner->banner_images()->saveMany($images);  
                
            }

        }catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('data.bannerscategory')->with('success', 'Banner category added successfully');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
        try{ 

             $banner = BannerCategory::with('banner_images')->where('id', $id)->first();
    
          }
          catch (\Illuminate\Database\QueryException $e) {
              return back()->withError($e->getMessage())->withInput();
          }


         return view('bannermanager::Admin.banners.show',compact('banner'));
      
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        try{ 

            $banner = BannerCategory::with('banner_images')->where('id', $id)->first();
   
         }
         catch (\Illuminate\Database\QueryException $e) {
             return back()->withError($e->getMessage())->withInput();
         }
         return view('bannermanager::Admin.banners.edit',compact('banner'));
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(BannerRequest $request, $id)
    {  
     
        try{
            
            $banner = BannerCategory::find($id);
            $banner->fill($request->all());
            $banner->save();
if($request->banner_images){
            $images =[];

            foreach ($request->banner_images as $key => $value) {
            //dd($value);
            $destination='/banner-images/';

            $img_name=$value['image'];

            #### move file from temp to banner-images ####

                if(\Storage::disk('public')->exists('temp/' . $img_name))
                {  
                    \Storage::disk('public')->move(
                    'temp/' . $img_name, $destination . $img_name);

                }

                  #### move file from temp to banner-images ####

                   if(!empty($value['id'])){
                      BannerImage::where('id', $value['id'])
                      ->update($value);
                    }
                    else{
                         $images[] = new BannerImage($value);
                    }
                }
                 $banner->banner_images()->saveMany($images);
            }
            
          }
          catch (\Illuminate\Database\QueryException $e) {
              return back()->withError($e->getMessage())->withInput();
          }
            return redirect()->route('data.bannerscategory')->with('success', 'Banner updated successfully!');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy($id)
    {
        try{ 

            DB::delete('delete from banner_categories where id = ?',[$id]);
   
         }
         catch (\Illuminate\Database\QueryException $e) {
             return  ['status' => false, 'message' => $e->getMessage(), 'data' => ['id' => $id]];
         }
        
        $responce = ['status' => true, 'message' => 'Banner has been deleted successfully !!', 'data' => ['id' => $id]];

        return $responce;
    }

    public function imagedelete($id)
    {  
        try{ 

            DB::delete('delete from banner_images where id = ?',[$id]);
   
         }
         catch (\Illuminate\Database\QueryException $e) {
             return  ['status' => false, 'message' => $e->getMessage(), 'data' => ['id' => $id]];
         }
       
        $responce = ['status' => true, 'message' => 'Banner image has been deleted successfully !!', 'data' => ['id' => $id]];

        return $responce;
    }

}
