<?php
namespace Modules\CargoCategoryManager\Http\Controllers\Admin;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;

use Modules\CargoCategoryManager\Entities\CargoCategory;
use Modules\CargoCategoryManager\Http\Requests\GeneralRequest;

use DB;

class CargoCategoryManagerController extends Controller
{

    
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function getCargoCategory(Request $request)
    {
       $allowed_columns = ['id', 'title', 'slug'];
        $sort = in_array($request->get('sort'), $allowed_columns) ? $request->get('sort') : 'created_at';
        $order = $request->get('direction') === 'asc' ? 'asc' : 'desc';
        $settings = CargoCategory::orderBy($sort, $order)->where('status',0)->paginate(config('get.ADMIN_PAGE_LIMIT'));
        
        return view('cargocategorymanager::Admin.cargo_categories.cargo.general-setting',compact('settings'));

    }
 /**
     * Show the form for creating a new resource.
     * @return Response
     */
     public function addCargoCategory()
    {
        return view('cargocategorymanager::Admin.cargo_categories.cargo.add');
    }
 /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function storeCargoCategory(GeneralRequest $request)
    {
        
        try{


            $cargoBanner = CargoCategory::create($request->all());
            if ($request->hasFile('banner')) {
        #### cargo banner upload script ####
            $imageName = 'cargo-banner-'.time().'.' . $request->file('banner')->getClientOriginalExtension();
            $request->file('banner')->move(public_path('cargo-banner'), $imageName);
        #### cargo banner upload script ####
            
            $cargoId = $cargoBanner->id;
            $updatecargo = CargoCategory::find($cargoId);
            $updatecargo->banner = $imageName;
            $updatecargo->save();
           }

        }catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('cargo_category.cargo')->with('success', 'Cargo category added successfully');
    }
  /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function showCargoCategory($id)
    {
        try{


            $settings = CargoCategory::find($id);

        }catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        
        return view('cargocategorymanager::Admin.cargo_categories.cargo.show',compact('settings'));
    }
/**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function editCargoCategory($id)
    {
        try{


            $settings = CargoCategory::find($id);

        }catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return view('cargocategorymanager::Admin.cargo_categories.cargo.add',compact('settings'));
    }

 /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function updateCargoCategory(GeneralRequest $request, $id)
    {
        try{
            $category = CargoCategory::find($id);
            $category->fill($request->all());
            $category->save();

             if ($request->hasFile('banner')) {
              #### cargo banner upload script ####
            $imageName = 'cargo-banner-'.time().'.' . $request->file('banner')->getClientOriginalExtension();
            $request->file('banner')->move(public_path('cargo-banner'), $imageName);
        #### cargo banner upload script ####
             
            $cargoId = $category->id;
            $updatecargo = CargoCategory::find($cargoId);
            $updatecargo->banner = $imageName;
            $updatecargo->save();
             }



          }
          catch (\Illuminate\Database\QueryException $e) {
              return back()->withError($e->getMessage())->withInput();
          }
            return redirect()->route('cargo_category.cargo')->with('success', 'Cargo category updated successfully!');
    }

/**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */

public function deleteCargoCategory(Request $request, $id)
    {
        try{


            $getCategoriesUpdated = DB::table('cargo_categories')
            ->where('id', '=', $id)
            ->update(['status' => 1]);

        }catch (\Illuminate\Database\QueryException $e) {
            return  ['status' => false, 'message' => $e->getMessage(), 'data' => ['id' => $id]];
        }
        
          $responce = ['status' => true, 'message' => 'Cargo category has been deleted successfully !!', 'data' => ['id' => $id]];

        return $responce;
        
    }


    
}