<?php

namespace Modules\CategoryManager\Entities;

use Illuminate\Database\Eloquent\Model;
use Kalnoy\Nestedset\NodeTrait;
use App\Events\Sluggable;

class Category extends Model
{
    use NodeTrait;
    use Sluggable; // Attach the Sluggable trait to the model


    protected $fillable = ['parent_id', 'title', 'slug', 'banner', 'meta_title', 'meta_keyword', 'meta_description', 'status', 'lft', 'rgt', 'depth'];
   // protected $fillable = [];


   public function sluggable() {
        return [
            'dbfield' => 'slug',
            'source' => 'title',
            'table' => 'categories',
        ];
    }

   public function getLftName()
   {
       return 'lft';
   }

   public function getRgtName()
   {
       return 'rgt';
   }

   public function getParentIdName()
   {
       return 'parent_id';
   }

   /**
     * Set the category title.
     *
     * @param  string  $value
     * @return void
     */
    public function setTitleAttribute($value)
    {
        $this->attributes['title'] = ucwords($value);
    }

    public function parent_category() {
        return $this->belongsTo(\Modules\CategoryManager\Entities\Category::class, 'parent_id', 'id');
    }

   public function products() {
        return $this->hasMany(\Modules\ProductManager\Entities\Product::class);
    }


    /**
     * Scope a query to only include active users.
     *
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeStatus($query, $status = null)
    {
        if ($status === '0' || $status == 1) {
            $query->where('status', $status);
        }
        return $query;
    }

    /**
     * Scope a query to only include filtered users.
     *
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeFilter($query, $keyword)
    {
        if (!empty($keyword)) {
            $query->where(function ($query) use ($keyword) {
                $query->where('title', 'LIKE', '%' . $keyword . '%');
                $query->orWhere('slug', 'LIKE', '%' . $keyword . '%');
                $query->orWhere('meta_description', 'LIKE', '%' . $keyword . '%');
            });
        }
        return $query;
    }

    /**
     * Scope a query to only include search category products.
     *
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeCategoryWise($query, $category_id)
    {
        if (!empty($category_id)) {
            $rootIds = \Modules\CategoryManager\Entities\Category::descendantsOf($category_id)->where('status', '=', 1)->pluck('id')->toArray();
            $rootIds[] = $category_id;
            $query->whereIn('id', $rootIds);
        }
        return $query;
    }

}
