<?php

namespace Modules\InterestManager\Entities;

use DB;
use Illuminate\Database\Eloquent\Model;

class PointInterest extends Model
{
    protected static function boot()
    {
        parent::boot();
		
		//point_interests

        static::deleting(function ($product) {
            //$product->product_images()->delete();
            foreach ($product->interest_image as $pimageObj) {
                $pimageObj->delete();
            }
        });
    }

    protected $fillable = ['location_id', 'type', 'title', 'description', 'ip','latitude', 'longitude', 'status', 'info_description', 'fdescription','sort_order'];

    /**
     * Set the category title.
     *
     * @param  string  $value
     * @return void
     */
    public function setTitleAttribute($value)
    {
        $this->attributes['title'] = ucwords($value);
    }

	public function locations(){
      
	    //return $this->belongsTo('Modules\LocationManager\Entities\Location');
		return $this->belongsTo(\Modules\LocationManager\Entities\Location::class, 'location_id', 'id');
    }   

   public function interest_images()
    {
        return $this->hasMany(\Modules\InterestManager\Entities\InterestImage::class, 'point_interest_id', 'id')->orderBy('sort_order', 'ASC');
    }
	
	 public function interest_videos()
    {
        return $this->hasMany(\Modules\InterestManager\Entities\InterestVideo::class, 'point_interest_id', 'id')->orderBy('sort_order', 'ASC');
    }

	 public function interest_audios()
    {
        return $this->hasMany(\Modules\InterestManager\Entities\InterestAudio::class, 'point_interest_id', 'id')->orderBy('sort_order', 'ASC');
    }
	
    public function main_image()
    {
        return $this->hasOne(\Modules\InterestManager\Entities\InterestImage::class, 'point_interest_id', 'id')->orderBy('sort_order', 'ASC');
    }

    /**
     * Scope a query to only include active users.
     *
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeStatus($query, $status = null)
    {
        if ($status === '0' || $status == 1) {
            $query->where('status', $status);
        }
        return $query;
    }

    /**
     * Scope a query to only include filtered users.
     *
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeFilter($query, $keyword)
    {
        if (!empty($keyword)) {
            $query->where(function ($query) use ($keyword) {
                $query->where('title', 'LIKE', '%' . $keyword . '%');              
                $query->orWhere('description', 'LIKE', '%' . $keyword . '%');
            });
        }
        return $query;
    }

    /**
     * Scope a query to only include filtered users.
     *
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeMatchTitle($query, $keyword)
    {
        if (!empty($keyword)) {
            $query->where('title', 'LIKE', '%' . $keyword . '%');
        }
        return $query;
    }

    /**
     * Scope a query to only include filtered users.
     *
     * @param \Illuminate\Database\Eloquent\Builder $query
     * @return \Illuminate\Database\Eloquent\Builder
     */
    public function scopeNotids($query, $ids)
    {
        if (!empty($ids['notids'])) {
            $query->whereNotIn('id', $ids['notids']);
        }
        return $query;
    }

}
