<?php

namespace Modules\InterestManager\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
//use Illuminate\Support\Facades\DB;
use Modules\LocationManager\Entities\Location;
use Modules\InterestManager\Entities\PointInterest;
use Modules\InterestManager\Entities\InterestAudio;
use Modules\InterestManager\Entities\InterestImage;
use Modules\InterestManager\Entities\InterestVideo;
use Modules\InterestManager\Http\Requests\InterestRequest;

class InterestManagerController extends Controller {

    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index() {
        $allowed_columns = ['id', 'title'];
        $sort = in_array(request('sort'), $allowed_columns) ? request('sort') : 'created_at';
        $order = request('direction') === 'asc' ? 'asc' : 'desc';
        $interests = PointInterest::status(request('status'))->where(['type' => 'interest'])->filter(request('keyword'))->with('locations')->orderBy($sort, $order)->paginate(config('get.ADMIN_PAGE_LIMIT'));
        //dd($interests->toArray());

        return view('interestmanager::Admin.Interests.index', compact('interests'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create() {
        $image_type = array('main' => 'Main', 'plaque' => 'Plaque', 'festival' => 'Festival', 'local' => 'Local');
        $locations = Location::orderBy('name', 'DESC')->pluck('name', 'id')->toArray();

        return view('interestmanager::Admin.Interests.createOrUpdate', compact('locations', 'image_type'));
    }

    /**
     * Store a newly created resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function store(InterestRequest $request) {

        //dd($request->all());
        //DB::beginTransaction();
		
        try {
			
			$pointInterestData = $request->only(['location_id', 'title', 'latitude', 'longitude', 'status', 'description']);
			$pointInterestData['type'] = "interest";
			$pointInterestData['ip'] = $request->getClientIp();

            $user = PointInterest::create($pointInterestData);

            
            if (!empty($request->only(['interest_images']))) {
                $imgs = [];
                $imgData = $request->only(['interest_images']);
                $sort = 0;
                foreach ($imgData['interest_images'] as $pimage) {
                    if (!empty($pimage) && $pimage['image'] != Null) {
                        $pimage['sort_order'] = $sort++;
						$pimage['image_type'] = $pimage['image_type'];
                        $imgs[] = new InterestImage($pimage);
                    }
                }
                $user->interest_images()->saveMany($imgs);
            }
            if (!empty($request->only(['interest_audios']))) {
                $audios = [];
                $audData = $request->only(['interest_audios']);
                $sort = 0;
                foreach ($audData['interest_audios'] as $paudio) {
                    if (!empty($paudio) && !empty($paudio['audio'])) {
                        $audio = $paudio['audio'];
                        $input = time() . '.' . $audio->getClientOriginalExtension();
                        $destinationPath = storage_path('app/public/interest');
                        $audio->move($destinationPath, $input);
                        $paudio['audio'] = $input;
						$paudio['audio_description'] = $paudio['audio_description'];
						$paudio['image_type'] = $paudio['image_type'];
                        $paudio['sort_order'] = $sort++;
                        $audios[] = new InterestAudio($paudio);
                    }
                }
                $user->interest_audios()->saveMany($audios);
            }
            if (!empty($request->only(['interest_videos']))) {
                $videos = [];
                $videoData = $request->only(['interest_videos']);
                $sort = 0;
                //dd($videoData['interest_videos']);die;
                foreach ($videoData['interest_videos'] as $pvideo) {
                    if (!empty($pvideo) && (!empty($pvideo['video']) || !empty($pvideo['video_id']))) {

                        if (!empty($pvideo['video'])) {
                            $video = $pvideo['video'];
                            $input = time() . '.' . $video->getClientOriginalExtension();
                            $destinationPath = storage_path('app/public/interest');
                            $video->move($destinationPath, $input);
                            $pvideo['video'] = $input;
							$pvideo['video_id'] = $pvideo['video_id'];
						    $pvideo['image_type'] = $pvideo['image_type'];
                        }

                        $pvideo['sort_order'] = $sort++;						
                        $videos[] = new InterestVideo($pvideo);
                    }
                }
                $user->interest_videos()->saveMany($videos);
            }
            // DB::commit();
        } catch (\Illuminate\Database\QueryException $e) {
            // DB::rollBack();
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('admin.interests.index', app('request')->query())->with('success', 'Interest has been saved Successfully');
    }

    /**
     * Store a newly created resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function tempcrop(Request $request) {
        $request->validate([
            'file' => 'required|image|mimes:jpeg,png,jpg|max:20000|dimensions:min_width=274,min_height=180',
                ], ['file.dimensions' => 'Image dimentions should be atleast 274x180']);
        $real_path = $request->file('file')->store('public/temp');
        $fake_path = str_replace("public/", "", $real_path);
        $image_path = asset("storage/" . $fake_path);
        $image_path = \App\Helpers\MenuHelpers::imageUrl(url($image_path), '274', '180', '100');
        $imageArray = explode("/", $fake_path);
        $imageName = end($imageArray);
        $fileList = "<i class='fa fa-check green'></i> " . $imageName . " file successfully uploaded!";
        return [
            'status' => TRUE,
            'responce' => 200,
            'message' => $fileList,
            'data' => ['filename' => $imageName, 'full_path' => $image_path, 'base_path' => $fake_path],
            '_jsonOptions' => JSON_FORCE_OBJECT,
            '_serialize' => ['status', 'responce', 'message', 'data']
        ];
    }

    public function storeTempImageDeleted(Request $request) {
        $real_path = $request->file('file')->store('public/temp');
        $fake_path = str_replace("public/", "", $real_path);
        $image_path = asset("storage/" . $fake_path);
        $imageArray = explode("/", $fake_path);
        $imageName = end($imageArray);
        return json_encode(['success' => true, 'image_path' => $image_path, 'fake_path' => $fake_path, 'filename' => $imageName]);
    }

    /**
     * Show the specified resource.
     * @return Response
     */
    public function show($id) {
        // try {
        //     $product = Product::findOrFail($id)->where('id' ,'=', $id)->with('product_images')->with('product_type')->with('category')->first();
        // }catch (\Illuminate\Database\Eloquent\ModelNotFoundException $exception) {
        //     echo $exception->getMessage();die;
        // }
        $interest = PointInterest::findOrFail($id)->where('id', '=', $id)->with('locations')->with('interest_images')->first();

        return view('interestmanager::Admin.Interests.show', compact('interest'));
    }

    /**
     * Show the form for editing the specified resource.
     * @return Response
     */
    public function edit($id) {
        $interest = PointInterest::where('id', '=', $id)->with('interest_images')->with('interest_audios')->with('locations')->with('interest_videos')->first();
        $locations = Location::orderBy('name', 'DESC')->pluck('name', 'id')->toArray();
        $image_type = array('main' => 'Main', 'plaque' => 'Plaque', 'festival' => 'Festival', 'local' => 'Local');
        return view('interestmanager::Admin.Interests.createOrUpdate', compact('locations', 'interest', 'image_type'));
    }

    /**
     * Update the specified resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function update(InterestRequest $request, $id) {

        try {

            if (empty($request->input('location_id'))) {
                $request['location_id'] = 0;
            }
           

            $user = PointInterest::find($id);
            $inputs = $request->except(['interest_images']);
            $inputs = $request->except(['interest_audios']);
            $inputs = $request->except(['interest_videos']);

            $user->fill($request->except(['interest_images']));
            $user->fill($request->except(['interest_audios']));
            $user->fill($request->except(['interest_videos']));
            $user['ip'] = $request->getClientIp();
            $user['type'] = 'interest';
            $user->save();

            if (!empty($request->only(['interest_images']))) {
                $imgs = [];
                $imgData = $request->only(['interest_images']);
                $sort = 0;
                foreach ($imgData['interest_images'] as $pimage) {
                    if (!empty($pimage) && $pimage['image'] != Null) {
                        $pimage['sort_order'] = $sort++;
                        if (isset($pimage['id'])) {
                            InterestImage::whereId($pimage['id'])->update($pimage);
                        } else {
                            $imgs[] = new InterestImage($pimage);
                        }
                    }
					else{
						$pimaget['image_type'] = $pimage['image_type'];
						 if (isset($pimage['id'])) {
							InterestImage::whereId($pimage['id'])->update($pimaget);
						 }
					}
                }
                $user->interest_images()->saveMany($imgs);
            }
            //Audio		
            $audios = [];

            if (!empty($request->only(['interest_audios']))) {

                $audioData = $request->only(['interest_audios']);
                $asort = 0;

                foreach ($audioData['interest_audios'] as $paudio) {

                    if (!empty($paudio) && !empty($paudio['audio'])) {
                        $audio = $paudio['audio'];
                        $input = time() . '.' . $audio->getClientOriginalExtension();
                        $destinationPath = storage_path('app/public/interest');
                        $audio->move($destinationPath, $input);
                        $paudio['audio'] = $input;
                        $paudio['sort_order'] = $asort++;
                        if (isset($paudio['id'])) {
                            InterestAudio::whereId($paudio['id'])->update($paudio);
                        } else {
                            $audios[] = new InterestAudio($paudio);
                        }
                    }
					else{
						 $paudiot['audio_description'] = $paudio['audio_description'];
						 $paudiot['image_type'] = $paudio['image_type'];
						 if (isset($paudio['id'])) {
							InterestAudio::whereId($paudio['id'])->update($paudiot);
						 }
					}
                }
                $user->interest_audios()->saveMany($audios);
            }

            //Video
            $videos = [];
			if (!empty($request->only(['interest_videos']))) {

                $videoData = $request->only(['interest_videos']);

                $vsort = 0;
                foreach ($videoData['interest_videos'] as $pvideo) {


                    if (!empty($pvideo) && !empty($pvideo['video'])) {
                        $video = $pvideo['video'];
                        $input = time() . '.' . $video->getClientOriginalExtension();
                        $destinationPath = storage_path('app/public/interest');
                        $video->move($destinationPath, $input);
                        $pvideo['video'] = $input;
                        $pvideo['sort_order'] = $vsort++;
						
                        if (isset($pvideo['id'])) {
                            InterestVideo::whereId($pvideo['id'])->update($pvideo);
                        } else {

                            $videos[] = new InterestVideo($pvideo);
                        }
                    }
					else{
						 $pvideot['video_id'] = $pvideo['video_id'];
						 $pvideot['image_type'] = $pvideo['image_type'];
						 if (isset($pvideo['id'])) {
							InterestVideo::whereId($pvideo['id'])->update($pvideot);
						 }
					}
                }

                $user->interest_videos()->saveMany($videos);
            }



            // DB::commit();
        } catch (\Illuminate\Database\QueryException $e) {
            // DB::rollBack();
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('admin.interests.index', app('request')->query())->with('success', 'Interest has been updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     * @return Response
     */
    public function destroy($id) {

        $interestType = PointInterest::find($id);
        try {
            $interestType->delete();
            $responce = ['status' => true, 'message' => 'This Interest has been deleted Successfully!', 'data' => $interestType];
        } catch (\Exception $e) {
            $responce = ['status' => false, 'message' => $e->getMessage()];
        }
        return $responce;
    }

    /**
     * Remove the specified resource from storage.
     * @return Response
     */
    public function deleteImage(Request $request) {
        $interestImage = InterestImage::find($request->input('id'));
        try {
            $interestImage->delete();
            $responce = ['status' => true, 'message' => 'This interest image has been deleted Successfully!', 'data' => $interestImage];
        } catch (\Exception $e) {
            $responce = ['status' => false, 'message' => $e->getMessage()];
        }
        return $responce;
    }

    /**
     * Remove the specified resource from storage.
     * @return Response
     */
    public function deleteAudio(Request $request) {
        $interestAudio = InterestAudio::find($request->input('id'));
        try {
            $interestAudio->delete();
            $responce = ['status' => true, 'message' => 'This interest image has been deleted Successfully!', 'data' => $interestAudio];
        } catch (\Exception $e) {
            $responce = ['status' => false, 'message' => $e->getMessage()];
        }
        return $responce;
    }

    /**
     * Remove the specified resource from storage.
     * @return Response
     */
    public function deleteVideo(Request $request) {
        $interestVideo = InterestVideo::find($request->input('id'));
        try {
            $interestVideo->delete();
            $responce = ['status' => true, 'message' => 'This interest image has been deleted Successfully!', 'data' => $interestVideo];
        } catch (\Exception $e) {
            $responce = ['status' => false, 'message' => $e->getMessage()];
        }
        return $responce;
    }

}
