<?php

namespace Modules\InterestManager\Observers;

use Modules\InterestManager\Entities\InterestImage;
use Illuminate\Support\Facades\Storage;

class InterestImageObserver
{
    /**
     * Handle the product image "created" event.
     *
     * @param  \App\InterestImage  $interestImage
     * @return void
     */
    public function created(InterestImage $interestImage)
    {
        $this->imageUploadAndUpdate($interestImage);
    }

    /**
     * Handle the product image "updated" event.
     *
     * @param  \App\InterestImage  $interestImage
     * @return void
     */
    public function updated(InterestImage $interestImage)
	{
        $this->imageUploadAndUpdate($interestImage);
    }

public function imageUploadAndUpdate($interestImage){
    if(!empty($interestImage->getAttribute('image'))){        
            if($interestImage->getAttribute('image') != $interestImage->getOriginal('image')){
                $existNew = Storage::disk('public')->exists('temp/'.  $interestImage->getAttribute('image'));
                if($existNew){
                    Storage::move('public/temp/' . $interestImage->getAttribute('image'), 'public/interest/' . $interestImage->getAttribute('image'));
                }

                $exists = Storage::disk('public')->exists('interests/'.  $interestImage->getOriginal('image'));
                if($exists){
                    Storage::disk('public')->delete('interests/'. $interestImage->getOriginal('image'));
                }
            }
        }
}

    /**
     * Handle the product image "deleted" event.
     *
     * @param  \App\InterestImage  $interestImage
     * @return void
     */
    public function deleted(InterestImage $interestImage)
    {
        $exists = Storage::disk('public')->exists('interests/'.  $interestImage->getAttribute('image'));
        if($exists){
            Storage::disk('public')->delete('interests/'. $interestImage->getAttribute('image'));
        }
    }

    /**
     * Handle the product image "restored" event.
     *
     * @param  \App\InterestImage  $interestImage
     * @return void
     */
    public function restored(InterestImage $interestImage)
    {
        //
    }

    /**
     * Handle the product image "force deleted" event.
     *
     * @param  \App\InterestImage  $interestImage
     * @return void
     */
    public function forceDeleted(InterestImage $interestImage)
    {
        echo "force";
        dd($interestImage);
    }
}
