<?php

namespace Modules\LocationManager\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\LocationManager\Entities\Location;
use Modules\LocationManager\Http\Requests\LocationsRequest;

class LocationsController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index(Request $request)
    {
        $allowed_columns = ['id', 'name'];
        $sort = in_array($request->get('sort'), $allowed_columns) ? $request->get('sort') : 'created_at';
        $order = $request->get('direction') === 'asc' ? 'asc' : 'desc';
        $locations = Location::orderBy($sort, $order)->paginate(config('get.ADMIN_PAGE_LIMIT'));
        return view('locationmanager::Admin.locations.index',compact('locations'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        return view('locationmanager::Admin.locations.createOrUpdate');
    }

    /**
     * Store a newly created resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function store(LocationsRequest $request)
    {       
	   try{
		    $request['ip'] =$request->getClientIp();
            Location::create($request->all());			
        }
        catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('admin.locations.index')->with('success', 'Location has been saved Successfully');
    }

    /**
     * Show the specified resource.
     * @return Response
     */
    public function show(Location $location)
    {
		return view('locationmanager::Admin.locations.show', compact('location'));
    }

    /**
     * Show the form for editing the specified resource.
     * @return Response
     */
    public function edit($id)
    {
        $locations = Location::find($id);
        return view('locationmanager::Admin.locations.createOrUpdate', compact('locations'));
    }

    /**
     * Update the specified resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function update(LocationsRequest $request, $id)
    {
        try{
            $location = Location::find($id);
            $location->fill($request->all());
			$location['ip'] =$request->getClientIp();
            $location->save();
          }
          catch (\Illuminate\Database\QueryException $e) {
              return back()->withError($e->getMessage())->withInput();
          }
        return redirect()->route('admin.locations.index')->with('success', 'Location has been updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     * @return Response
     */
    public function destroy()
    {
    }
}
