<?php

namespace Modules\PriceRangeManager\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\PriceRangeManager\Entities\PriceRange;
use Illuminate\Support\Facades\DB;
use Modules\PriceRangeManager\Http\Requests\PriceRangeRequest;
class PriceRangesController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index(Request $request)
    {
        $allowed_columns = ['id', 'title', 'slug'];
        
        $order = $request->get('direction') === 'asc' ? 'asc' : 'asc';
        $pricerange = PriceRange::status(request('status'))->filter(request('keyword'))->orderBy('title', 'desc')->paginate(config('get.ADMIN_PAGE_LIMIT'));
        
        return view('pricerangemanager::admin.price_range.index', compact('pricerange'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        
        return view('pricerangemanager::admin.price_range.createOrUpdate');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(PriceRangeRequest $request)
    {
       $input=$request->all();
       unset($input['_token']);
         try{
            PriceRange::create($input);
            
        }
        catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->to(url('admin/price-ranges'))->with('success', 'Price Range has been saved Successfully');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
        try{
            $price_range = PriceRange::find($id);
            
        }
        catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return view('pricerangemanager::admin.price_range.show',compact('price_range'));
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        try{
            $price_range = PriceRange::find($id);
            
        }
        catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
       
        
        return view('pricerangemanager::admin.price_range.createOrUpdate',compact('price_range'));
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(PriceRangeRequest $request, $id)
    {
        
        try{
            $pricerange = PriceRange::find($id);
            $pricerange->fill($request->all());
            $pricerange->save();
          }
          catch (\Illuminate\Database\QueryException $e) {
              return back()->withError($e->getMessage())->withInput();
          }
          return redirect()->to(url('admin/price-ranges'))->with('success', 'price range has been updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     * @return Response
     */
     public function destroy($id)
     {
         DB::beginTransaction();
         $pricerange = PriceRange::where('id', '=', $id)->first();
       
        try{
         $pricerange->delete();
         DB::commit();
         $responce =  ['status' => true,'message' => 'This price range has been deleted Successfully!','data' => $pricerange];
     }
     catch (\Exception $e)
     {
         DB::rollBack();
         $responce =  ['status' => false,'message' => $e->getMessage()];
     }
     return $responce;
 
     }
}
