<?php

namespace Modules\ServiceManager\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\ServiceManager\Entities\Service;
use Modules\ServiceManager\Http\Requests\ServiceRequest;

class ServiceController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index()
    {

        $services = Service::orderBy('id')->paginate(config('get.ADMIN_PAGE_LIMIT'));
        return view('servicemanager::Admin.index',compact('services'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        return view('servicemanager::Admin.add');
    }

    /**
     * Store a newly created resource in storage.
     * @param Request $request
     * @return Response
     */
    public function store(ServiceRequest $request)
    {
        try{
             
             $slug=$request->input('slug');
              
             $Service = new Service();
 
             $Service->title = request('title');
            
             $Service->description = request('description');

            if(Service::whereSlug($slug)->exists())
            {           $i = 1;
                        $Service->slug=$slug . '-' . ++$i;
            }
            else{
                        $Service->slug= $slug;
            }
          // dd($request);            
 
            $Service->save();

            //$Service = Service::create($request->all());
          

        }catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('data.service')->with('success', 'service added successfully');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
        try{
            $service = Service::find($id);
         }
        catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
         
        return view('servicemanager::Admin.show',compact('service'));
    }

    /**
     * Show the form for editing the specified resource.
     * @param int $id
     * @return Response
     */
    public function edit($id)
    {
        try{
            $service = Service::find($id);
         }
        catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return view('servicemanager::Admin.add',compact('service'));
    }

    /**
     * Update the specified resource in storage.
     * @param Request $request
     * @param int $id
     * @return Response
     */
    public function update(ServiceRequest $request, $id)
    { //dd($request->input());
       try{ 
            $Service = Service::find($id);
            $Service->fill($request->all());
            $Service->save(); 
          }
          catch (\Illuminate\Database\QueryException $e) {
              return back()->withError($e->getMessage())->withInput();
          }
            return redirect()->route('data.service')->with('success', 'Service updated successfully!');
    }

    /**
     * Remove the specified resource from storage.
     * @param int $id
     * @return Response
     */
    public function destroy($id)
    {
        try{
            $Service = Service::find($id);
            $Service->delete();
         }
        catch (\Illuminate\Database\QueryException $e) {
            return  ['status' => false, 'message' => $e->getMessage(), 'data' => ['id' => $id]];
        }
        
 
        $responce = ['status' => true, 'message' => 'Service has been deleted successfully !!', 'data' => ['id' => $id]];

        return $responce;
    }
}
