<?php

namespace Modules\FaqManager\Http\Controllers\Admin;

use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\FaqManager\Entities\Faq;
use Modules\FaqManager\Http\Requests\FaqsRequest;

/**
 * Faqs Controller
 *
 * @property  Modules\FaqManager\Entities\Faq $faq;
 *
 * @method \Modules\FaqManager\Entities\Faq[] index(Request $request), create, store(FaqsRequest $request), show(Faq $faq), edit($id), update(FaqsRequest $request, $id), destroy($id)
 */
class FaqsController extends Controller
{

    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index(Request $request) {
        $allowed_columns = ['id', 'question', 'answer', 'status'];
        $sort            = in_array($request->get('sort'), $allowed_columns) ? $request->get('sort') : 'created_at';
        $order           = $request->get('direction') === 'asc' ? 'asc' : 'desc';

        $query = Faq::status($request->query('status'))->filter($request->query('keyword'))->orderBy($sort, $order);
        $faqs  = $query->paginate(config('get.ADMIN_PAGE_LIMIT'));
        return view('faqmanager::Admin.faqs.index', compact('faqs'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create() {
        return view('faqmanager::Admin.faqs.createOrUpdate');
    }

    /**
     * Store a newly created resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function store(FaqsRequest $request) {
        try {
            Faq::create($request->all());
        } catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('admin.faqs.index')->with('success', 'Faq has been saved Successfully');
    }

    /**
     * Show the specified resource.
     * @return Response
     */
    public function show(Faq $faq) {

        return view('faqmanager::Admin.faqs.show', compact('faq'));
    }

    /**
     * Show the form for editing the specified resource.
     * @return Response
     */
    public function edit($id) {
        $faq = Faq::find($id);
        return view('faqmanager::Admin.faqs.createOrUpdate', compact('faq'));
    }

    /**
     * Update the specified resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function update(FaqsRequest $request, $id) {
        try {
            $faq = Faq::find($id);
            $faq->fill($request->all());
            $faq->save();
        } catch (\Illuminate\Database\QueryException $e) {
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('admin.faqs.index')->with('success', 'Faq has been updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     * @return Response
     */
    public function destroy($id) {

        DB::beginTransaction();
        $faq = Faq::find($id);
        // $faq->roles()->detach();
        try {
            $faq->delete();
            DB::commit();
            $responce = ['status' => true, 'message' => 'This faq has been deleted Successfully!', 'data' => $faq];
        } catch (\Exception $e) {
            DB::rollBack();
            $responce = ['status' => false, 'message' => $e->getMessage()];
        }
        return $responce;
    }

}
