<?php

namespace Modules\SubscriptionManager\Http\Controllers\Admin;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\SubscriptionManager\Entities\SubscriptionPlan;
use Modules\SubscriptionManager\Entities\SubscriptionPlanFeature;
use Modules\SubscriptionManager\Http\Requests\SubscriptionPlanRequest;
use Illuminate\Support\Facades\DB;
class SubscriptionPlansController extends Controller
{
   /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index(Request $request) {
       // dd(\Config::get('constant.plan_features'));
        SubscriptionPlanFeature::whereNotIn('title',array_keys(\Config::get('constant.plan_features')))->delete();
        $allowed_columns = ['email'];
        $sort            = in_array($request->get('sort'), $allowed_columns) ? $request->get('sort') : 'created_at';
        $order           = $request->get('direction') === 'asc' ? 'asc' : 'desc';

        $query = SubscriptionPlan::filter($request->query('keyword'))->status(request('status'))->orderBy($sort, $order);
        $plans  = $query->paginate(config('get.ADMIN_PAGE_LIMIT'));
        return view('subscriptionmanager::Admin.subscription_plan.index', compact('plans'));
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {

        return view('subscriptionmanager::Admin.subscription_plan.createOrUpdate');
    }

    /**
     * Store a newly created resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function store(SubscriptionPlanRequest $request)
    {
        DB::beginTransaction();
        try{
        $inputs =  $request->except(['SubscriptionPlan_images']);
           $plan = SubscriptionPlan::create($inputs);
           if(!empty($request->only(['subscription_plan_features']))){
            $features=[];
            $Data = $request->only(['subscription_plan_features']);
            $metaData = [];
            foreach($Data['subscription_plan_features'] as $record){
                if(!empty($record) && $record['title']!=Null && $record['value']!=Null){
                    $metaData[$record['title']] = $record['value'];
                    $features[] = new SubscriptionPlanFeature($record);
                    // SubscriptionPlanImage::whereId($pimage['id'])->update($pimage);
                }
            }
            $plan->subscription_plan_features()->saveMany($features);
          }
      
         /* $data = [
            "nickname"  => $request->input('title'),
            "amount"    => $request->input('amount') * 100,
            "interval"  => $request->input('plan_interval'),
            "trial_period_days" => $request->input('trail_days'),
            "active" => $request->input('status') == 1 ? true : false,
            "product" => [
              "name" => $request->input('title'),
              "type" => 'service',
              "metadata" => $metaData,
            ],
            "metadata" => $metaData,
            "currency" => strtolower(getBaseCurrency()),
        ];
        $result = (new \App\Stripe\Payment)->createPlan($data);
        $getPlan = SubscriptionPlan::find($plan->id);
        $getPlan->stripe_product_id = $result['data']->product;
        $getPlan->stripe_plan_id = $result['data']->id;
        $getPlan->save();*/
        DB::commit();
        }
        catch (\Illuminate\Database\QueryException $e) {
            DB::rollBack();
            return back()->withError($e->getMessage())->withInput();
        }
        return redirect()->route('admin.subscriptionplans.index', app('request')->query())->with('success', 'Subscription plan has been saved Successfully');
    }

 /**
     * Show the form for editing the specified resource.
     * @return Response
     */
    public function edit($id)
    {
        $subscriptionPlan = SubscriptionPlan::where('id' ,'=', $id)->first();
        return view('subscriptionmanager::Admin.subscription_plan.createOrUpdate', compact('subscriptionPlan'));
    }

    /**
     * Update the specified resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function update(SubscriptionPlanRequest $request, $id)
    {
        //dd($request->all());
        DB::beginTransaction();
        try{
            $plan = SubscriptionPlan::find($id);

            $plan->fill($request->except(['subscription_plan_features']));
            $plan->save();
            if(!empty($request->only(['subscription_plan_features']))){
                $features=[];
                $Data = $request->only(['subscription_plan_features']);
                $existingfeatures=$plan->subscription_plan_features->pluck('id','title')->toArray();
                $metaData = [];
                foreach($Data['subscription_plan_features'] as $record){
                    if(array_key_exists($record['title'],\Config::get('constant.plan_features'))){
                        if(!empty($record) && $record['title']!=Null && $record['value']!=Null){
                            if(array_key_exists($record['title'],$existingfeatures)){
                                SubscriptionPlanFeature::whereId($existingfeatures[$record['title']])->update($record);
                            }
                            else{

                                $features[] = new SubscriptionPlanFeature($record);
                            }
                            $metaData[$record['title']] = $record['value'];
                    }

                    }else{
                        SubscriptionPlanFeature::where('title',$record['title'])->delete();
                    }
                }
                $plan->subscription_plan_features()->saveMany($features);

              }
/*
              $data = [
                "nickname" => $request->input('title'),
                "trial_period_days" => $request->input('trail_days'),
                "active" => $request->input('status') == 1 ? true : false,
                "metadata" => $metaData,
            ];
            $result = (new \App\Stripe\Payment)->updatePlan($plan->stripe_plan_id,$data);*/
            DB::commit();
          }
          catch (\Illuminate\Database\QueryException $e) {
            DB::rollBack();
            return back()->withError($e->getMessage())->withInput();
          }
        return redirect()->route('admin.subscriptionplans.index', app('request')->query())->with('success', 'SubscriptionPlan has been updated Successfully');
    }

    /**
     * Remove the specified resource from storage.
     * @return Response
     */
    public function destroy($id)
    {
        $SubscriptionPlanType = SubscriptionPlan::find($id);
        try{
            $SubscriptionPlanType->subscription_plan_features()->delete();
            $SubscriptionPlanType->delete();
          
            $responce =  ['status' => true,'message' => 'This SubscriptionPlan has been deleted Successfully!','data' => $SubscriptionPlanType];
        }
        catch (\Exception $e)
        {
            $responce =  ['status' => false,'message' => $e->getMessage()];
        }
        return $responce;
    }
 /**
     * Show the form for editing the specified resource.
     * @return Response
     */
    public function show($id)
    {
        $subscriptionPlan = SubscriptionPlan::where('id' ,'=', $id)->first();
        return view('subscriptionmanager::Admin.subscription_plan.show', compact('subscriptionPlan'));
    }
}
