<?php

namespace Modules\SubscriptionManager\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Http\Response;
use Illuminate\Routing\Controller;
use Modules\SubscriptionManager\Entities\SubscriptionPlan;
use Modules\SubscriptionManager\Entities\SubscriptionPlanFeature;
use Modules\SubscriptionManager\Http\Requests\CardRequest;
use Auth;
class SubscriptionPlansController extends Controller
{
    /**
     * Display a listing of the resource.
     * @return Response
     */
    public function index()
    {
        return view('subscriptionmanager::index');
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        return view('subscriptionmanager::create');
    }



    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function show($id)
    {
        return view('subscriptionmanager::show');
    }

    /**
     * Show the specified resource.
     * @param int $id
     * @return Response
     */
    public function pricing()
    {
        return view('subscriptionmanager::pricing');
    }


    public function subscriptionPlanList()
    {
        if(!Auth::user()){
            //return redirect()->route('login')->with('success', 'Please login to access this page.');
            return redirect()->route('login');
        }
        $plans = SubscriptionPlan::where('status',1)->orderBy('id','asc')->get();
        return view('subscriptionmanager::subscription_plan',compact('plans'));
    }
     /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function subscriptionForm($planId)
    {
        if(empty($planId))
        {
            return redirect()->back()->with('error', 'Invalid Plan Id.');
        }
        $title = "save card";
        $user = Auth::user();
        if($user->role_id == 1){
           abort(403);
        }
        $plan = SubscriptionPlan::whereId($planId)->first();

        if (!$plan) {
            return redirect()->back()->with('error', 'Invalid Plan Id.');
        }

        $amount = Auth::user()->currency_code == getBaseCurrency() ? format($plan->amount) : convert($plan->amount, getCurrencyData(getBaseCurrency())['rate'], getUserCurrency());


        if($user->subscribedToPlan($plan->stripe_plan_id, 'main')) {
            return redirect()->route('subscription-plan')->with('success', 'You have already subscribed the plan');
        }

        $address = Auth::user()->address;
        $existAddr = [];
        if(!empty($address->address_line_1))
            $existAddr[] = $address->address_line_1;
        if(!empty($address->address_line_2))
            $existAddr[] = $address->address_line_2;
        if(!empty($address->city))
            $existAddr[] = $address->city;
        if(!empty($address->state->title))
            $existAddr[] = $address->state->title;
        if(!empty($address->postal_code))
            $existAddr[] = $address->postal_code;
        if(!empty($address->country->title))
            $existAddr[] = $address->country->title;

        return view('subscriptionmanager::card', compact('title', 'plan','existAddr'));
    }
       /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request, $planId)
    {
    $authUser = Auth::user();
    $plan = SubscriptionPlan::find($planId);
    $user = \Modules\UserManager\Entities\User::where("id",Auth::user()->id)->with('address')->first();
    if($user->subscribedToPlan($plan->stripe_plan_id, 'main')) {
        $response = ['status' => false, 'message' => 'You have already subscribed the plan'];
    }else{
        if($user->subscription('main')){
            $user->subscription('main')->cancelNow();
        }
        if($plan->trail_days > 0){
           $subscribe = $user->newSubscription('main',@$plan->stripe_plan_id,['description' => $user->id . "User Subscription",
            'email' => $user->email, // obtained with Stripe.js
            'source' => $request->input('stripeToken')])
            ->trialDays($plan->trail_days)
            ->create($request->input('stripeToken'));
        }else{
            $subscribe = $user->newSubscription('main',@$plan->stripe_plan_id,['description' => $user->id . "User Subscription",
            'email' => $user->email, // obtained with Stripe.js
            'source' => $request->input('stripeToken')])
            ->skipTrial()
            ->create($request->input('stripeToken'));
        }

        if(!empty($subscribe->stripe_id)){
            $amount = Auth::user()->currency_code == getBaseCurrency() ? $plan->amount : convert($plan->amount, getCurrencyData(getBaseCurrency())['rate'], getUserCurrency(), false);
            $gst_tax = 0;
            if(Auth::user()->currency_code == "AUD"){
                $fee = iwhiz_fee();
                $gst_tax = ($fee['gst_tax']/100) * $plan->amount;
            }
            $transaction_arr = [];
            $transaction_arr['user_id'] = Auth::user()->id;
            $transaction_arr['amount'] = $plan->amount;// $amount;
            $transaction_arr['iwhiz_fee'] = 0;
            $transaction_arr['gst_fee'] = $gst_tax;
            $transaction_arr['total_amount'] = ($plan->amount + $gst_tax); //$amount;
            $transaction_arr['payment_token'] = $subscribe->stripe_id;
            $transaction_arr['payment_method'] = 'card';
            $transaction_arr['transaction_status'] = 1;
            $transaction_arr['transactionId'] = $subscribe->stripe_id;
            $transaction_arr['transaction_responce'] = json_encode($subscribe);
            $transaction_arr['currency_code'] = getBaseCurrency(); //Auth::user()->currency_code;
            $transaction_arr['currency_value'] = getCurrencyData(getBaseCurrency())['rate']; //Auth::user()->currency_value;
            $transaction_arr['supplier_currency_code'] = Auth::user()->currency_code; //getBaseCurrency();
            $transaction_arr['supplier_currency_value'] = Auth::user()->currency_value; //getCurrencyData(getBaseCurrency())['rate'];
            $transaction_arr['comments'] = Auth::user()->name. " has subscribed the plan";
            $transaction = \Modules\ProductManager\Entities\Transaction::create($transaction_arr);
            $transaction->subscription()->sync([$subscribe->id]);
            $response = ['status' => true, 'message' => '<strong>Success:</strong> The Subscription plan has been successfully subscribed.'];
            $details = [
                'description' => 'You have successfully subscribed the '.$plan->title,
                'url' => '',
            ];
            $user->notify(new \App\Notifications\CustomNotification($details));
            $data['plan'] = $plan->toArray();
            $data['user'] = $user->toArray();
            $data['transaction'] = $transaction;
            $data['subscribe'] = $subscribe->toArray();
            $data['amount'] = format($plan->amount, Auth::user()->currency_code);
            if(Auth::user()->currency_code == "AUD"){
                $data['gst_tax'] = format($gst_tax, Auth::user()->currency_code);
                $data['total_amount'] = format(($plan->amount + $gst_tax), Auth::user()->currency_code);
            }
            $invoiceAtachment = (new \App\Common)->generateSubscriptionInvoice($data);
            $attachement = [];
           if($invoiceAtachment){
                $mime = mime_content_type(public_path().'/storage/invoice/'.$invoiceAtachment);
                $attachement['fullpath'] = public_path().'/storage/invoice/'.$invoiceAtachment;
                $attachement['specify'] = ['as' => $plan->title. '.pdf','mime' => $mime];
           }
           (new \App\Common)->planEmail($data, $attachement);

        }else{
            $response = ['status' => false, 'message' => config('message.SaveCardFailed')];
        }
    }
        return $response;

    }
}
