<?php

namespace App\Http\Controllers\Api\v1;

use Illuminate\Support\Facades\Hash;
use App\Models\Community;
use App\Models\Enquiry;
use Illuminate\Http\Request;
use App\Http\Controllers\Controller;
use Illuminate\Support\Str;
use App\Traits\ApiGlobalFunctions;
use DB;
use Validator;
use Config;

class CommunityController extends Controller {

    use ApiGlobalFunctions;

    public function listing(Request $request) {
		$input = $request->all();
       try {
            $query = Community::query();
			$query->with(['SubDetail'=>function($q){
				$q->select(['id','community_id','sub_title','questions']);
				$q->with(['Answer'=>function($qry){
					return $qry->select(['id','community_subdetail_id','answer']);
				}]);
				return $q;
			}]);
			$query->where('status', 1)->orderBy('title','ASC');
			$community = $query->get();
            if (count($community) > 0){
				$data['community'] = $community; 
                return $this->sendResponse($data, $this->messageDefault('record_found'));
            } else {
                return $this->sendError($this->messageDefault('record_not_found'), '', '200');
            }
        } catch (\Exception $e) {
            return $this->sendError($e); 
            return $this->sendError($this->messageDefault('oops'), '', '200');
        }
    }
	
	
	/**
     * Register api
     *
     * @return \Illuminate\Http\Response
     */
    public function contactUs(Request $request) {

        $input = $request->all();

        try {
            $enquiry = new Enquiry();
            $validator = Validator::make($request->all(), [
                        'email' => 'required|email',
                        'message' => 'required',
                        'name' => 'required',
                        'subject' => 'required',
                            ], [
                        'name.required' => 'Please enter your name.',
                        'email.required' => 'Please enter your email address.',
                        'subject.required' => 'Please enter your subject.',
                        'message.required' => 'Please enter your message',
            ]);
            if ($validator->fails()) {
                return $this->sendError('Validation Error.', $validator->errors()->first(), '200');
            }

            $enquiry->email_address = $input['email'];
            $enquiry->name = $input['name'];
            $enquiry->subject = $input['subject'];
            $enquiry->message = $input['message'];
            $enquiry->save();
            if ($enquiry) {
                //\Mail::to($udata->email)->send(new VerifyUserMail($udata));

                return $this->sendResponse([], $this->messageDefault('save_records'));
            } else {
                return $this->sendError($this->messageDefault('save_failed'), '', '200');
            }
        } catch (\Exception $e) {

            return $this->sendError($this->messageDefault('oops'), '', '200');
        }
    }

	public function checkUpdate(){
		
		//DB::table('settings')->where('slug', 'LASTUPDATE')->update(['config_value' => date('Y-m-d H:s:i')]);
				
		$site_settings = DB::table('settings')->pluck('config_value','slug');
		 
		if (isset($site_settings['LASTUPDATE'])){
			$data['last_sync'] = $site_settings['LASTUPDATE']; 
			return $this->sendResponse($data, $this->messageDefault('record_found'));
		} else {
			return $this->sendError($this->messageDefault('record_not_found'), '', '200');
		}
	}
}
